@@ -12,9 +12,11 @@ from mcdbot.errors.object_errors import BadMcPlayerError, McPlayerAlreadyRegiste
 from mcdbot.errors.password_errors import McPasswordInvalidUnderPolicyError
 from discord import Member, User
 from typing import Union
+from loguru import logger
 
 
 def check_user(main: Mcdbot, user: Union[Member, User]):
+    logger.debug(f"Checking user {user}...")
     if isinstance(user, Member):
         return True
     if main.main_guild.get_member(user.id) is not None:
